@@ -3,6 +3,7 @@
 import gettext
 import os
 import re
+import subprocess
 import sys
 import time
 import tkinter as tk
@@ -18,16 +19,25 @@ from tkinter.ttk import *
 import cv2
 import numpy as np
 import yaml
-from cv2 import haarcascades
+
+try:
+    from cv2 import haarcascades
+except BaseException:
+    from cv2.data import haarcascades
+else:
+    print('haarcascades could not be imported, funing exit.')
+    exit()
+
+
 from PIL import Image, ImageTk
 
 from funing import *
 from funing._ui import error
-from funing._ui.lang import _
+from funing.locale import _
 from funing.ui.about_ui import about_toplevel
 from funing.ui.main_ui import MainUI
 
-# from funing._ui.lang import _
+# from funing.locale import _
 # self.frame_width, self.frame_height, __ = self.cur_frame.shape
 
 
@@ -44,15 +54,10 @@ class FUV():
         self.click_to_remove_p = _('Click the picked face image to remove.')
         self.double_click_to_remove_r = \
             _('Double click the face image to remove.')
-
-        self.image_exts = [
-            'jpg', 'png', 'jpeg', 'webp'
-        ]
-        self.video_exts = [
-            'mp4', 'avi', '3gp', 'webm', 'mkv'
-        ]
-        self.filetype_exts = '*.' + \
-            ' *.'.join(self.image_exts + self.video_exts)
+        self.image_exts = ['jpg', 'png', 'jpeg', 'webp']
+        self.video_exts = ['mp4', 'avi', '3gp', 'webm', 'mkv']
+        self.filetype_exts = '*.' + ' *.'.join(
+            self.image_exts + self.video_exts)
 
 
 class SourceType(Enum):
@@ -68,47 +73,45 @@ class FDoing(Enum):
 
 class _MainUI():
     def __init__(self):
+
+        # enum
+        self.fuv = FUV()
+        self.fdoing = FDoing.PICK
+
+        # ui
         self.mainui = MainUI()
         self.mainui.place()
-
-        self.fuv = FUV()
-
-        self.source = -1
-        self.root_after = -1
-        self.fxfy = None
-        self.showf_sv = None
         self.showfm = self.mainui.showframe
         self.infofm = self.mainui.infoframe
-        self.bottomframe = self.mainui.bottomframe
-        self.status_label_sv = self.bottomframe.status_label_sv
+        self.bottomfm = self.mainui.bottomframe
+        self.status_label_sv = self.bottomfm.status_label_sv
         self.about_tl = None
+        self.showf_sv = None
+
         # vid
         self.vid = None
-        self.frame_width = 0
-        self.frame_height = 0
+        self.frame_width = self.frame_height = 0
         self.vid_fps = 0
-
+        self.fxfy = None
+        self.source = -1
         self.source_type = SourceType.NULL
+        self.paused = False
 
+        # vid frame
         self.cur_frame = None
         self.face_rects = []
-        self.picked_face_frames = []
-        self.showed_face_frames = []
+        self.picked_face_frames = self.showed_face_frames = []
         self.show_size = (200, 200)
         self.zoom_in_size = (210, 210)
         self.save_size = (100, 100)
         self.zoomed_in_face_label = (0, 0)
-
-        self.fdoing = FDoing.PICK
-
-        self.paused = False
-        # rec_result
         self.rec_gray_img = None
-        # rec_faces
-        self.recfs = []
+        self.root_after = -1
+
         # info
         self.cur_info_id = None
         self.info_ids = []
+
         # cv2
         self.hff_xml_path = os.path.join(haarcascades,
                                          "haarcascade_frontalface_default.xml")
@@ -122,11 +125,17 @@ class _MainUI():
         except BaseException:
             print(_('No desktop environment is detected! '))
             exit()
+
+        # train recognizer
         if data_empty():
             self.show_status_msg(self.fuv.nothing_was_entered_str)
         else:
             self.recognizer_train()
+
+        # events
         self.set_ui_events()
+
+        # mainloop
         self.mainui.mainloop()
 
     def load_images(self):
@@ -153,14 +162,19 @@ class _MainUI():
         labels = np.asarray(labels)
         return images, labels, ids
 
-    def about_tl_destroy(self):
-        self.about_tl.destroy()
-        self.about_tl = None
+    def recognizer_train(self):
+        self.show_status_msg(_('Recognizer training. . .'))
+        images, labels, self.info_ids = self.load_images()
+        self.recognizer.train(images, labels)
+        self.show_status_msg(_('Recognizer finish training.'))
+
+    def ipynb_fn(self):
+        subprocess.Popen(f'cd {user_ipynb_dir_path} && jupyter-notebook',
+                         shell=True)
 
     def about_fn(self):
         if self.about_tl is None:
             self.about_tl = about_toplevel()
-            self.about_tl.protocol("WM_DELETE_WINDOW", self.about_tl_destroy)
             self.about_tl.mainloop()
         else:
             self.about_tl.destroy()
@@ -170,12 +184,6 @@ class _MainUI():
     def show_status_msg(self, msg):
         self.status_label_sv.set(msg)
 
-    def recognizer_train(self):
-        self.show_status_msg(_('Recognizer training. . .'))
-        images, labels, self.info_ids = self.load_images()
-        self.recognizer.train(images, labels)
-        self.show_status_msg(_('Recognizer finish training.'))
-
     def open_vid_cap(self):
         self.vid = cv2.VideoCapture(self.source)
         if not self.vid.isOpened():
@@ -198,7 +206,8 @@ class _MainUI():
         self.showfm.showf_go_btn['command'] = self.show_go
         self.showfm.showf_optionmenu_sv.trace('w', self.show_from)
         self.infofm.save_btn['command'] = self.savef
-        self.bottomframe.about_fn_btn['command'] = self.about_fn
+        self.bottomfm.about_fn_btn['command'] = self.about_fn
+        self.bottomfm.ipynb_fn_btn['command'] = self.ipynb_fn
         self.mainui.root.protocol("WM_DELETE_WINDOW", self.destroy)
 
     def destroy(self):
@@ -295,17 +304,21 @@ class _MainUI():
                 title=_('Select a file'),
                 filetypes=[(_('Image or video'), self.fuv.filetype_exts)],
                 initialdir='~')
+
             if len(self.face_src_path) < 1:
                 return
+
             ext = os.path.splitext(self.face_src_path)[1][1:]
             self.showfm.showf_sv.set(self.face_src_path)
+
             if ext in self.fuv.image_exts:
                 self.view_image()
             elif ext in self.fuv.video_exts:
                 self.source = self.face_src_path
                 self.play_video()
+
         elif show_f == 'camera':
-            self.source = 0
+            self.source = self.showf_sv = 0
             self.showfm.showf_sv.set(self.source)
             self.play_video()
 
@@ -431,7 +444,8 @@ class _MainUI():
             return
         info = self.infofm.face_text.get("1.0", "end-1c")
         info_file_path = os.path.join(infos_path, self.cur_info_id)
-        open(info_file_path, 'w+').write(info)
+        with open(info_file_path, 'w+') as f:
+            f.write(info)
         if self.fdoing == FDoing.PICK:
             img_path = os.path.join(faces_path, self.cur_info_id)
             os.makedirs(img_path, exist_ok=True)
