@@ -11,6 +11,10 @@ def fp(content):
     print('::::::::::::::::::::::::::::::::::::::::::::')
 
 
+def notebook_nf():
+    fp_r_i('notebook', 'https://jupyter.org/install')
+
+
 def read_install(notfound, url):
     try:
         webbrowser.open(url)
@@ -47,7 +51,7 @@ def f_r_nf():
 def db_no_col(db_path=''):
     if len(db_path) > 0:
         db_path = f'({db_path})'
-    fp(f'Add specific column to database{db_path} ')
+    fp(f'Add specific column to database {db_path} ')
 
 
 def lib_check():
