@@ -4,7 +4,7 @@ from tkinter import *
 from tkinter.ttk import *
 
 from funing import *
-from funing._ui.lang import _
+from funing.locale import _
 
 
 class AboutToplevel():
@@ -23,8 +23,16 @@ class AboutToplevel():
             "<Button-1>",
             lambda e: webbrowser.open_new(source_page))
         self.source_page_label.pack()
+        self.about_tl.protocol("WM_DELETE_WINDOW", self.destroy)
         Label(self.about_tl, text=_('Licensed under the MIT license')).pack()
         Label(self.about_tl, text=_('From larryw3i & contributors')).pack()
 
+    def destroy(self):
+        self.about_tl.destroy()
+        self.about_tl = None
+
+    def mainloop(self):
+        self.about_tl.mainloop()
+
 
 def about_toplevel(): return AboutToplevel().about_tl
